import type { JSXChildren, QRL, JSXNode } from "@builder.io/qwik"

export type BaseClassNames = {
  // Class name for <td> tag
  td?: string
  // Custom class name for each column (identified by heading name)
  tcol?: {
    [heading: string]: string
  }
}

export type THeadClassNames = BaseClassNames & {
  // Class name for <thead> tag
  thead?: string
  // Class name for <th> tag
  th?: string
}

export type TBodyClassNames = BaseClassNames & {
  // Class name for <tbody> tag
  tbody?: string
  // Class name for <tr> tag
  tr?: string
}

export type TableClassNames = TBodyClassNames &
  THeadClassNames & {
    // Class name for <table> tag
    table?: string
  }

export type THeadProps = {
  // List of table headings
  headings: Array<string>
  // Custom headings
  customHeadings:
    | undefined
    | {
        [heading: string]: string
      }
  // List of class names within <thead> tag
  classNames: THeadClassNames
}

export type CellData = {
  [key: string]: JSXChildren
}

export type TBodyProps = {
  // Table data
  data: Array<CellData>
  // List of table headings
  headings: Array<string>
  // List of class names within <tbody> tag
  classNames: TBodyClassNames
  // Rendered elements
  element?: {
    [key: string]: QRL<(record: CellData, param: string) => JSXNode | string>
  }
}

export type TableData = {
  // Table data
  tData: Array<CellData>
  // Rendered elements
  element?: {
    [key: string]: QRL<(record: CellData, param: string) => JSXNode | string>
  }
  // Table options
  tableOptions?: {
    // Custom headings
    customHeadings?: {
      [heading: string]: string
    }
    // List of class names
    classNames?: TableClassNames
  }
}
